primecount: Algorithms for counting primes
==========================================

Description
-----------

primecount is a C++ implementation of several algorithms for counting
primes maintained by Kim Walisch.

Website: https://github.com/kimwalisch/primecount/

License
-------

primecount is licensed BSD 2


Upstream Contact
----------------

-  https://github.com/kimwalisch/primecount/
